# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .database_column_info import DatabaseColumnInfo


class DatabaseTableSchemaResponse(UniversalBaseModel):
    """
    Response for table schema (columns and types).
    """

    columns: typing.List[DatabaseColumnInfo] = pydantic.Field()
    """
    List of columns with their types and constraints
    """

    schema_: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="schema")] = pydantic.Field(
        default=None
    )
    """
    Schema containing the table
    """

    table_name: str = pydantic.Field()
    """
    Name of the table
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
